@@ -39,4 +39,8 @@ class Thoonk(BaseConnection):
         return Pubsub(host=self.host, port=self.port, db=self.db, listen=self.listen)
 
     def disconnect(self):
-        self.pubsub.close()
+        self.connection.close()
+
+    def flushdb(self):
+        """the tests assume this function exists for all redis-like backends"""
+        self.connection.redis.flushdb()
